@@ -1,7 +1,6 @@
 from abc import ABC, abstractmethod
 import logging
 import os
-from pathlib import Path
 import time
 import traceback
 from typing import Callable
@@ -9,6 +8,7 @@ from typing import Callable
 from .env import (
     ENGINE,
     ENGINE_EXECO,
+    ENGINE_FILE,
     ENGINE_GOOGLE,
     ENV_DRY_MODE,
     ENGINE_PULSAR,
@@ -142,6 +142,42 @@ class ProcessCallback(DefaultCallback):
                 raise e
 
 
+class DockerCallback(DefaultCallback):
+    """A callback that starts  docker container upon the reception of params.
+
+    User should probably define the to_kwargs method that tells how the
+    params are passed to the docker client.
+    The possible keyword arguments can be found here:
+    https://docker-py.readthedocs.io/en/stable/containers.html#docker.models.containers.ContainerCollection.run
+
+    By default **param is passed.
+    """
+
+    def __init__(self, image: str):
+        """Create a DockerCallback instance.
+
+        This relies on the docker python client:
+        https://pypi.org/project/docker/
+
+        Args:
+            image: the docker image to use
+        """
+        self.image = image
+        import docker
+
+        self.client = docker.from_env()
+
+    def to_kwargs(self, param: Param):
+        return param
+
+    def process(self, param: Param, engine: Engine):
+        kwargs = self.to_kwargs(param)
+        # force some options here
+        kwargs.update(detach=False, stdout=True, stderr=True)
+        logs = self.client.containers.run(self.image, **kwargs)
+        print(logs)
+
+
 class FuncCallback(DefaultCallback):
     """A callback that minionizes a python function.
 
@@ -232,6 +268,11 @@ def create_engine():
 
         return PulsarPubSub.from_env()
 
+    if ENGINE == ENGINE_FILE:
+        from minionize.file import File
+
+        return File.from_env()
+
     raise Exception(f"EntryPoint {ENGINE} not supported")
 
 
@@ -241,4 +282,4 @@ def minionizer(callback: Callback):
     engine = create_engine()
     reporter = create_reporter()
 
-    return EntryPoint(callback, engine, reporter)
+    return EntryPoint(callback, engine, reporter)
\ No newline at end of file
