@@ -391,7 +391,7 @@ def summary(df: pd.DataFrame) -> Section:
     - {success} generations have been successfuly treated. This corresponds
       to the number of parameters for which a result has been produced.
     - {len(df) - success} error have been detected
-    Doing the maths, approximately {round(error_rate, 2)}% of the generations failed.
+    Doing the maths, approximately {round(error_rate, 2)*100}% of the generations failed.
 
     Results arrived at the mean rate of {round(success_rate_arrival, 2)} per second.
 
